@@ -2,12 +2,32 @@
 # Replace all occurences with commented function
 clean_script <- function(file, message=FALSE, target=c("rmd", "html")){
   target <- match.arg(target)
-  noRunFunctions <- c("quit", "readClipboard", "RSiteSearch", "install.packages", "update.packages", "savehistory", "loadhistory", "findFn", "vignette", "png", "trellis.device", "dev.off", "save", "load")
-  ptn <- sprintf("^!( *#* *).*%s", paste0("(", noRunFunctions, "\\(", ")", collapse="|"))
+  noRunFunctions <- c("quit", 
+                      "readClipboard", 
+                      "RSiteSearch", 
+                      "install.packages", 
+                      "update.packages", 
+                      "savehistory", 
+                      "loadhistory", 
+                      "findFn", 
+                      "vignette", 
+                      "png", 
+                      "trellis.device", 
+                      "dev.off", 
+                      "save", 
+                      "load"
+                      )
+  ptn <- sprintf("^!( *#* *).*%s", 
+                 paste0("(", noRunFunctions, "\\(", ")", collapse="|"))
   
-  ptn <- sprintf("^[^ #]*.*(%s)\\(", paste(noRunFunctions, collapse="|"))
+  ptn <- sprintf("^[^ #]*.*(%s)\\(",
+                 paste(noRunFunctions, collapse="|"))
   if(!file.exists(file)) stop("file doesn't exist")
-  txt <- scan(file, what="character", sep="\n", quiet=TRUE, blank.lines.skip = FALSE)
+  txt <- scan(file, 
+              what="character", 
+              sep="\n", 
+              quiet=TRUE, 
+              blank.lines.skip = FALSE)
   
   # Remove fancy quotes
   txt <- gsub("â€™", "'", txt, useBytes=TRUE)  ## fancy single quote
@@ -49,8 +69,12 @@ clean_script <- function(file, message=FALSE, target=c("rmd", "html")){
 
 # Run clean_script for all scripts in inst/scripts/1-orig, putting cleaned version in inst/scripts/2-clean
 clean_all_scripts <- function(scriptPath, outPath, comment=TRUE, message=TRUE){
-  if(!file.exists(scriptPath)) stop("script path doesn't exist")
-  scripts <- normalizePath(list.files(scriptPath, pattern="\\.R$", full.names = TRUE))
+  if(!file.exists(scriptPath)) {
+    stop("script path doesn't exist")
+  }
+  scripts <- normalizePath(list.files(scriptPath, 
+                                      pattern="\\.R$", 
+                                      full.names = TRUE))
   clean <- lapply(scripts, clean_script, message=message)
   ret <- sapply(seq_along(scripts), function(i){
     newFile <- file.path(outPath, basename(scripts[i]))
@@ -62,7 +86,9 @@ clean_all_scripts <- function(scriptPath, outPath, comment=TRUE, message=TRUE){
   invisible(ret)
 }
 
-clean_all_scripts(scriptPath = "rfordummies/inst/scripts/1-orig", outPath = "rfordummies/inst/scripts/2-clean")
+clean_all_scripts(scriptPath = "rfordummies/inst/scripts/1-orig", 
+                  outPath = "rfordummies/inst/scripts/2-clean"
+                  )
 
 
 
